<template>
    <div class="container">
      <h1 class="fs-3 fl-4">Resend Verification Email</h1>
      <p class="fl-5">After sending email, check your inbox of <b>{{ state.$claims.email }}</b></p>
      <p class="fl-5">
        <div class="mt-8 actions">
          <button class="mr-4 btn btn-primary" type="button" @click="resendVerificationEmail" :disabled="state.$waiting">
            <span v-if="state.$waiting" class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Resend Verification Email</button>
          <button class="btn btn-secondary" type="button" @click="cancel">Cancel</button>
        </div>
      </p>
    </div>
  </template>

<script setup>
const password = ref ('')
const { state } = useStore ()

function cancel () {
  router.back ()
}

async function resendVerificationEmail () {
  password.value = "111111"

  state.$waiting = true
  let errorMessage = ''
  try {
    const auth = await firebase.getAuth ()
    const userCredential = await firebase.auth.signInWithEmailAndPassword(auth, state.$claims.email, password.value)

    if (!state.$claims.email.endsWith ('@kracknet.com')) {
      await firebase.auth.sendEmailVerification (userCredential.user)
    }
  } catch (error) {
    return frontend.handle_firebase_error (error, "Send Verification Email")
  }
  state.$waiting = false
  bootstrap.toast ({title: "Success", text: "Verification email has been successfully sent."})
  router.push ('/')
}

onActivated (() => {
  frontend.set_title ()
})

</script>

<script>
export default {
  async beforeRouteEnter (to, from, next) {
    await frontend.permission.required ([], {path: '/members/signin'}, {to, from, next})
    if (store.state.$grp.indexOf ("guest") == -1) {
      router.push ('/')
    }
  }
}
</script>
